@@ -6,7 +6,7 @@ The file parser that handles the parsing of CHGCAR files.
 """
 
 from aiida_vasp.parsers.file_parsers.parser import BaseFileParser
-from aiida_vasp.parsers.node_composer import NodeComposer
+from aiida_vasp.parsers.node_composer import NodeComposer, get_node_composer_inputs_from_file_parser
 
 
 class ChgcarParser(BaseFileParser):
@@ -23,7 +23,6 @@ class ChgcarParser(BaseFileParser):
     def __init__(self, *args, **kwargs):
         super(ChgcarParser, self).__init__(*args, **kwargs)
         self._chgcar = None
-        self.init_with_kwargs(**kwargs)
 
     def _parse_file(self, inputs):
         """Create a DB Node for the CHGCAR file."""
@@ -41,6 +40,6 @@ class ChgcarParser(BaseFileParser):
     @property
     def chgcar(self):
         if self._chgcar is None:
-            composer = NodeComposer(file_parsers=[self])
-            self._chgcar = composer.compose('vasp.chargedensity')
+            inputs = get_node_composer_inputs_from_file_parser(file_parser=self)
+            self._chgcar = NodeComposer.compose('vasp.chargedensity', inputs)
         return self._chgcar
