@@ -8,7 +8,7 @@ import re
 
 from parsevasp.outcar import Outcar
 from aiida_vasp.parsers.file_parsers.parser import BaseFileParser, SingleFile
-from aiida_vasp.parsers.node_composer import NodeComposer
+from aiida_vasp.parsers.node_composer import NodeComposer, get_node_composer_inputs_from_file_parser
 
 DEFAULT_OPTIONS = {'quantities_to_parse': ['elastic_moduli', 'symmetries']}
 
@@ -53,17 +53,37 @@ class OutcarParser(BaseFileParser):
             'name': 'site_magnetization',
             'prerequisites': []
         },
+        'run_stats': {
+            'inputs': [],
+            'name': 'run_stats',
+            'prerequisites': [],
+        }
     }
 
     def __init__(self, *args, **kwargs):
+        """
+        Initialize OUTCAR parser
+
+        file_path : str
+            File path.
+        data : SingleFileData
+            AiiDA Data class install to store a single file.
+        settings : ParserSettings
+
+        """
+
         super(OutcarParser, self).__init__(*args, **kwargs)
         self._outcar = None
-        self.init_with_kwargs(**kwargs)
+        self._settings = kwargs.get('settings', None)
+        if 'file_path' in kwargs:
+            self._init_outcar(kwargs['file_path'])
+        if 'data' in kwargs:
+            self._init_outcar(kwargs['data'].get_file_abs_path())
 
-    def _init_with_file_path(self, path):
+    def _init_outcar(self, path):
         """Init with a filepath."""
         self._parsed_data = {}
-        self.parsable_items = self.__class__.PARSABLE_ITEMS
+        self._parsable_items = self.__class__.PARSABLE_ITEMS
         self._data_obj = SingleFile(path=path)
 
         # Since OUTCAR can be fairly large, we will parse it only
@@ -74,11 +94,6 @@ class OutcarParser(BaseFileParser):
             self._logger.warning('Parsevasp exited abruptly. Returning None.')
             self._outcar = None
 
-    def _init_with_data(self, data):
-        """Init with SingleFileData."""
-        self.parsable_items = self.__class__.PARSABLE_ITEMS
-        self._init_with_file_path(data.get_file_abs_path())
-
     def _parse_file(self, inputs):
 
         # Since all quantities will be returned by properties, we can't pass
@@ -87,8 +102,8 @@ class OutcarParser(BaseFileParser):
             self._parsed_data[key] = value
 
         quantities_to_parse = DEFAULT_OPTIONS.get('quantities_to_parse')
-        if self.settings is not None and self.settings.quantities_to_parse:
-            quantities_to_parse = self.settings.quantities_to_parse
+        if self._settings is not None and self._settings.quantity_names_to_parse:
+            quantities_to_parse = self._settings.quantity_names_to_parse
 
         result = {}
 
@@ -105,6 +120,11 @@ class OutcarParser(BaseFileParser):
 
         return result
 
+    @property
+    def run_stats(self):
+        """Fetch the run statistics"""
+        return self._outcar.get_run_stats()
+
     @property
     def symmetries(self):
         """Fetch the symmetries, but only the point group (if it exists)."""
@@ -181,7 +201,6 @@ class LegacyOutcarParser(BaseFileParser):
     def __init__(self, *args, **kwargs):
         super(LegacyOutcarParser, self).__init__(*args, **kwargs)
         self._parameter = None
-        self.init_with_kwargs(**kwargs)
 
     def _parse_file(self, inputs):
         """Add all quantities parsed from OUTCAR to _parsed_data."""
@@ -245,6 +264,6 @@ class LegacyOutcarParser(BaseFileParser):
     @property
     def parameter(self):
         if self._parameter is None:
-            composer = NodeComposer(file_parsers=[self])
-            self._parameter = composer.compose('parameter', quantities=DEFAULT_OPTIONS)
+            inputs = get_node_composer_inputs_from_file_parser(self, quantity_keys=DEFAULT_OPTIONS['quantities_to_parse'])
+            self._parameter = NodeComposer.compose('dict', inputs)
         return self._parameter
