@@ -1,8 +1,11 @@
-""" # noqa: D205
-Inheritance tools
------------------
 """
-import six
+Inheritance tools.
+
+------------------
+This sets up inheritance of the docstrings for use when we inherit
+classes. This makses it simple to add further details to or replace the
+docstring present on the base class.
+"""
 
 
 def update_docstring(method_name, content, append=True):
@@ -11,8 +14,6 @@ def update_docstring(method_name, content, append=True):
 
     For subclasses that use hooks to change behaviour of superclass methods.
 
-    This is only applied for Python 3.
-
     :param append: If true, append to the docstring, else overwrite it entirely.
 
     Example::
@@ -41,12 +42,11 @@ def update_docstring(method_name, content, append=True):
     """
 
     def wrapper(cls):
-        """Update the method docstring and return the class. Only works for Python 3."""
-        if six.PY3:
-            if append:
-                getattr(cls, method_name).__func__.__doc__ = ""
-            else:
-                getattr(cls, method_name).__func__.__doc__ = content
+        """Update the method docstring and return the class."""
+        if append:
+            getattr(cls, method_name).__func__.__doc__ = ''
+        else:
+            getattr(cls, method_name).__func__.__doc__ = content
         return cls
 
     return wrapper
